//File provides code fragment which writes the MQCIH struct into a MQMessage object (client or bindings)


//MQPUT block follows
try
{
  MQMessage  putMsg =    new MQMessage();

  //set MQMD as required
  putMsg.format="MQCICS  ";                    //value of MQFMT_CICS
  putMsg.encoding=MQC.MQENC_INTEGER_NORMAL;    //Big-endian integers, as in Java
  putMsg.characterSet=819;                     //Internal logic defaults this to 819,
                                               //however recommend in this case that you explicitly
                                               //set the value for use in the CIH value
                                               //set affects the codepage used to writeString()
                            

  //write MQCIH struct into message buffer
  //based on description of MQCIH struct in APR
  //as constants are not predefined in MQC, need to define or simply write in defaults

  putMsg.writeString("CIH ");           //MQCHAR4   StrucId;            /* Structure identifier */
  putMsg.writeInt(1);                   //MQLONG    Version;            /* Structure version number 1 or 2 */
  putMsg.writeInt(164);                 //MQLONG    StrucLength;        /* Length of MQCIH structure V1=164 V2=180 */
  putMsg.writeInt(putMsg.encoding);     //MQLONG    Encoding;           /* Reserved */
  putMsg.writeInt(putMsg.characterSet); //MQLONG    CodedCharSetId;     /* Reserved */
  putMsg.writeString(MQC.MQFMT_NONE);   //MQCHAR8   Format;             /* MQ Format name */
  putMsg.writeInt(0);                   //MQLONG    Flags;              /* Reserved */
  putMsg.writeInt(0);                   //MQLONG   ReturnCode;          /* Return code from bridge */          
  putMsg.writeInt(0);                   //MQLONG   CompCode;            /* MQ completion code or CICS          
                                                                           EIBRESP */                          
  putMsg.writeInt(0);                   //MQLONG   Reason;              /* MQ reason or feedback code, or CICS 
                                                                           EIBRESP2 */                         
  putMsg.writeInt(273);                 //MQLONG   UOWControl;          /* Unit-of-work control */             
  putMsg.writeInt(-2);                  //MQLONG   GetWaitInterval;     /* Wait interval for MQGET call issued 
                                                                           by bridge */                        
  putMsg.writeInt(1);                   //MQLONG   LinkType;            /* Link type */                        
  putMsg.writeInt(-1);                  //MQLONG   OutputDataLength;    /* Output commarea data length */      
  putMsg.writeInt(0);                   //MQLONG   FacilityKeepTime;    /* Bridge facility release time */     
  putMsg.writeInt(0);                   //MQLONG   ADSDescriptor;       /* Send/receive ADS descriptor */      
  putMsg.writeInt(0);                   //MQLONG   ConversationalTask;  /* Whether task can be                 
                                                                           conversational */                   
  putMsg.writeInt(0);                   //MQLONG   TaskEndStatus;       /* Status at end of task */            
  byte [] temp = new byte[8];           //initialise as required
  putMsg.writeByte(temp);               //MQBYTE   Facility[8];         /* BVT token value */
  putMsg.writeString("    ");           //MQCHAR4  Function;            /* MQ call name or CICS EIBFN function 
                                                                           name */                             
  putMsg.writeString("    ");           //MQCHAR4  AbendCode;           /* Abend code */                       
  putMsg.writeString("        ");       //MQCHAR8  Authenticator;       /* Password or passticket */           
  putMsg.writeString("        ");       //MQCHAR8  Reserved1;           /* Reserved */                         
  putMsg.writeString(MQC.MQFMT_NONE);   //MQCHAR8  ReplyToFormat;       /* MQ format name of reply message */  
  putMsg.writeString("    ");           //MQCHAR4  RemoteSysId;         /* Remote sysid to use */              
  putMsg.writeString("    ");           //MQCHAR4  RemoteTransId;       /* Remote transid to attach */         
  putMsg.writeString("    ");           //MQCHAR4  TransactionId;       /* Transaction to attach */            
  putMsg.writeString("    ");           //MQCHAR4  FacilityLike;        /* Terminal emulated attributes */     
  putMsg.writeString("    ");           //MQCHAR4  AttentionId;         /* AID key */                          
  putMsg.writeString("    ");           //MQCHAR4  StartCode;           /* Transaction start code */           
  putMsg.writeString("    ");           //MQCHAR4  CancelCode;          /* Abend transaction code */           
  putMsg.writeString("    ");           //MQCHAR4  NextTransactionId;   /* Next transaction to attach */       
  putMsg.writeString("        ");       //MQCHAR8  Reserved2;           /* Reserved */                         
  putMsg.writeString("        ");       //MQCHAR8  Reserved3;           /* Reserved */                         

  //Version 2 fields
  putMsg.writeInt(0);                   //MQLONG   CursorPosition;      /* Cursor position */
  putMsg.writeInt(0);                   //MQLONG   ErrorOffset;         /* Error offset */
  putMsg.writeInt(0);                   //MQLONG   InputItem;           /* Input item */
  putMsg.writeInt(0);                   //MQLONG   Reserved4;           /* Reserved */


  //put message to queue (assumed MQQueue queue opened elsewhere)
  pmo = new MQPutMessageOptions();
  queue.put(putMsg,pmo);    

}
catch(MQException ex)
{
  System.err.println("MQPUT failed with error code: " + ex.reasonCode);
}

